==> haskell-hslua-module-system-0.2.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-3G9zn1qSwpF4PxXi7cQpls
key: hslua-module-system-0.2.1-3G9zn1qSwpF4PxXi7cQpls
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: 78de2bfde4093c28059537da5fb372b5
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-3G9zn1qSwpF4PxXi7cQpls
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.2-HDaOvlvHbPR767FjhdL1tt
    hslua-1.0.3.2-Hz3Qp38q0XT5iT6agbZDLA
    temporary-1.3-LlCRdZN5kP3FxzYC5G3hZS
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-0.2.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-BIMEpJMjVYv7Xke1DIGA3s
key: hslua-module-system-0.2.1-BIMEpJMjVYv7Xke1DIGA3s
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: e1d1a4cb19d4533b7654d9127543f248
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-BIMEpJMjVYv7Xke1DIGA3s
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    hslua-1.0.3.2-Fs6khi7Cq5y8CwYMQ4vQZm
    temporary-1.3-F6xRo1rNLbCADrAA6svjLo
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
